@@ -38,7 +38,7 @@ class ImageRecognition(object):
         self.classification_by_regression = classification_by_regression
 
         self.input_placeholder = tf.placeholder(tf.float32, shape=(None, self.input_height, self.input_width, self.input_channel))
-        self.output_placeholder = tf.placeholder(tf.float32, shape=(None, len(self.classes)))
+        
 
         if self.classification_by_regression: 
             if json_label_file is None: 
@@ -48,6 +48,11 @@ class ImageRecognition(object):
                 f = open(json_label_file)
                 self.regression_value = json.load(f)
 
+            self.output_placeholder = tf.placeholder(tf.float32, shape=(None, 1))
+        
+        else: 
+            self.output_placeholder = tf.placeholder(tf.float32, shape=(None, len(self.classes)))
+
 
     def build_resnetv2(self, 
                        input_tensor,
@@ -116,6 +121,7 @@ class ImageRecognition(object):
                 else:
                     out = tf.nn.softmax(out)
 
+        self.out = out
         return out, base_var_list
 
 
@@ -149,7 +155,7 @@ class ImageRecognition(object):
         with slim.arg_scope(arg_scope):
             # get output (logits)
             out, end_points = inception_v4(input_tensor, 
-                                           num_classes=100, 
+                                           num_classes=1001, 
                                            final_endpoint=final_endpoint, 
                                            is_training=is_training)
             # get inception variable name
@@ -158,7 +164,7 @@ class ImageRecognition(object):
         with tf.variable_scope('InceptionV4'):
             size = out.get_shape().as_list()[1]
             while(True):
-                if size == 1:
+                if size <= 8:
                     break
 
                 out = new_conv2d_layer(out, 
@@ -237,7 +243,7 @@ class ImageRecognition(object):
         with tf.variable_scope('densenet121'):
             size = out.get_shape().as_list()[1]
             while(True):
-                if size == 1:
+                if size <= 8:
                     break
 
                 out = new_conv2d_layer(out, 
@@ -253,9 +259,10 @@ class ImageRecognition(object):
                                         use_bias=True,
                                         use_batchnorm=True) 
                 size = out.get_shape().as_list()[1]
-            
-            depth = out.get_shape().as_list()[-1]
+             
             out = tf.reshape(out, [tf.shape(out)[0], -1])
+            print (out)
+            depth =  out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
 
             if self.classification_by_regression:
                 out = new_fc_layer(out, 
